/***************************************************************************
 *   ICORP.H   - include file for Whaven game                              *
 *                                                                         *
 *                                                     12/15/94 Les Bird   *
 ***************************************************************************/

/* EG Bugfix #defines
 * ------------------
 * These all relate to bug and "bug" fixes that I've made optional
 * If you feel that one of these fixes is too "impure" then you can undefine
 * it for your port/mod.
 */
// Fire resistance won't resist non-fire projectiles (Disabled, breaks gameplay on some maps)
// #define FIX_FIRE_RESIST
// Make Onyx Ring do something (As Adamantine Ring, but for (non-fire, non-magic) projectiles instead of melee)
#define FIX_ONYX_RING
// Don't let projectiles collide with each other
#define FIX_PROJECTILE_COLLISION
// Don't mess with pentagram properties (originally cleared translucency off of exit marks)
#define FIX_PENTAGRAM_TRANS
// Don't count pentagrams towards the item score (could make it impossible to score all items)
#define FIX_PENTAGRAM_SCORE
// Fix faulty possiblities in treasure chest code
#define FIX_TREASURE_CHESTS
// Fix shocked status (originally did nothing)
#define FIX_SHOCKED
// Don't use & operator in randomizing functions
#define FIX_FLAKY_RANDOMIZER
// Shoot darts from approximate center of hole, even if scaled
#define FIX_DART_ORIGIN
// Powerups that are claimed to last one minute, do so
#define FIX_POWERUP_TIMES

// Serious changes to game mechanics due to cases where the manual seemed "right" while the code seemed "wrong"
// (Normally I defer to the code in case of discrepancies)
// Make magic arrows and fireballs work more like described in the manual
#define SPELLS_LIKE_MANUAL
// Give Midian Warriors different HP based on color
#define ADJUST_MIDIAN_HP

// Likewise, but these are more "tweaks" than "fixes"
// Aim less at enemy's feet
#define TWEAK_AUTOAIM

// Making defines for what was hardcoded
// The original value for this was 256
#define DEFAULT_PLR_ZOOM 64

// End EG bugfix #defines

/* EGwhaven 25 May 2015: define names for bit values to pass to rotatesprite */
#define ROTSPR_TRANSLUCENT    1
#define ROTSPR_SCALETOWINDOW  2
#define ROTSPR_YFLIP          4
#define ROTSPR_NOCLIPSTART    8
#define ROTSPR_TOPLEFTORIGIN  16
#define ROTSPR_REVERSETRANS   32
#define ROTSPR_UNMASKED       64
#define ROTSPR_ALLPAGES       128


#include <fcntl.h>
#include <io.h>
#include <sys\types.h>
#include <sys\stat.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <dos.h>
#include <setjmp.h>
#include <stdarg.h>
#include <process.h>

#include "build.h"
#include "names.h"
#include "les.h"
#include "jeff.h"
#include "raf.h"
#include "whdefs.h"
#include "keydefs.h"
#include "extern.h"
#include "pragmas.h"
#include "wh2cntrl.h"


#include "whaven.h"
#include "whinp.h"
#include "whtag.h"
#include "whobj.h"
#include "whplr.h"
#include "whfx.h"
#include "whsndmod.h"
#include "whani.h"
#include "whnet.h"
#include "cdrom.h"
#include "whctm.h"
#include "whsmk.h"
#include "readcfg.h"
//#include "profile.def"

// EG Bugfix Aug 15 2014: Work on timer accuracy stuff by moving the formula to a #define
// The original formula: (sintable[(lockclock << 4) & 2047])
// EG note: didn't actually fix anything this way, but I'm leaving it.
#define   CLOCKFORMULA  (sintable[(lockclock << 4) & 2047])

#define   GONZOGSHXR     35
#define   GONZOGSHYR     35
#define   GONZOGHMXR     35
#define   GONZOGHMYR     35
#define   GONZOGSWXR     35
#define   GONZOGSWYR     35
#define   NEWGUYXR       35
#define   NEWGUYYR       35
#define   GONZOCSWXR     35
#define   GONZOCSWYR     35
#define   GONZOCSWATXR   35
#define   GONZOCSWATYR   35
#define   KOBOLDXR       60
#define   KOBOLDYR       60
#define   DEVILXR        50
#define   DEVILYR        50
#define   IMPXR          25
#define   IMPYR          25
#define   MINOTAURXR     64
#define   MINOTAURYR     64
#define   SKELETONXR     35
#define   SKELETONYR     35
#define   GRONHALXR      35
#define   GRONHALYR      35
#define   GRONSWXR       35
#define   GRONSWYR       35
#define   GRONMUXR       35
#define   GRONMUYR       35
#define   WILLOWXR       35
#define   WILLOWYR       35
#define   DEMONXR        38
#define   DEMONYR        41
#define   GUARDIANXR     35
#define   GUARDIANYR     35
#define   KURTXR         35
#define   KURTYR         35
#define   KATIEXR        35
#define   KATIEYR        35

extern int  swingcnt;

struct swingdoor {
     int  wall[8];
     int  sector;
     int  angopen;
     int  angclosed;
     int  angopendir;
     int  ang;
     int  anginc;
     long x[8];
     long y[8];
};

extern
struct swingdoor swingdoor[MAXSWINGDOORS];

//
// plr->flags defines
//

//
// plr->equipment flag values
//


struct player {
     long x,y,z;
     long ang;
     long horiz;
     long zoom;
     long height;
     long hvel;               
     short sector,oldsector;
     short screensize;
     short spritenum;
     char dimension;
     unsigned long flags;
     int  weapon[MAXWEAPONS],preenchantedweapon[MAXWEAPONS];
     int  ammo[MAXWEAPONS],preenchantedammo[MAXWEAPONS];
     int  orbammo[MAXNUMORBS];
     int  treasure[MAXTREASURES];
     int  orbactive[MAXNUMORBS];
     int  orb[MAXNUMORBS];
     int  potion[MAXPOTIONS];
     int  lvl;
     long score;
     int  health;
     int  maxhealth;
     int  armor;
     int  armortype;
     char onsomething;
     long fallz;
};

extern struct player player[MAXPLAYERS];

struct delayitem {
     void (*func)(int);
     int  item;
     int  timer;
};

extern
struct delayitem delayitem[MAXSECTORS];

struct sectoreffect {
     unsigned long sectorflags;
     long animate;
     int  hi,lo;
     int  delay,delayreset;
};

extern
int  secnt,
     sexref[];

extern
struct sectoreffect sectoreffect[MAXSECTORS];

extern
int  pyrn;

extern
long angvel,
     svel,
     vel;

extern
long *animateptr[],
     animategoal[],
     animatevel[],
     animatecnt,
     neartagdist,
     neartaghitdist;

extern
unsigned long flags32[];

extern
short neartagsector,
     neartagwall,
     neartagsprite;

// EG Bugfix Aug 15 2014: Make lockclock work properly
extern
long lockspeed;
extern
long lockclock;

void lb_printf(int,int,char *,...);

// EGwhaven 21 Aug 2014: eg_gamedir
extern
char displaybuf[50],
     tempbuf[576],
     scorebuf[50],
     healthbuf[50],
     armorbuf[50],
     potionbuf[50],
     boardname[80],
     tempboard[80],
     loadgamename[80],
     scantoasc[128],
     scantoascwithshift[128],
     typemessage[162],
     fancy[41],
     eg_gamedir[16];

// EGWhaven 16 Jan 2015: for GAME parameter
extern int eg_gameflag;

#define   ARROWCOUNTLIMIT     100
#define   THROWPIKELIMIT      100

extern
short arrowsprite[ARROWCOUNTLIMIT],
     throwpikesprite[THROWPIKELIMIT];

